@@ -8,16 +8,18 @@ from morphapi.morphology.morphology import Neuron
     https://github.com/BrancoLab/BrainRender
 """
 
-fp = 'examples/example_files/example1.swc'
+fp = "examples/example_files/example1.swc"
 
 # Create vtkplotter actors from the .swc file
 neuron = Neuron(swc_file=fp)
-components, neuron = neuron.create_mesh(neurite_radius=3, #
-                soma_color='salmon', # Specify colors [see vtkplotter.colors for more details]
-                apical_dendrites_color='darkseagreen',
-                basal_dendrites_color='orangered',
-                axon_color='blackboard',
-                whole_neuron_color='blackboard')
+components, neuron = neuron.create_mesh(
+    neurite_radius=3,  #
+    soma_color="salmon",  # Specify colors [see vtkplotter.colors for more details]
+    apical_dendrites_color="darkseagreen",
+    basal_dendrites_color="orangered",
+    axon_color="blackboard",
+    whole_neuron_color="blackboard",
+)
 
 # components stores an actor for each neuronal component (dendrites, soma...)
 # neuron is a single actor for the entire neuron
@@ -26,5 +28,4 @@ components, neuron = neuron.create_mesh(neurite_radius=3, #
 # Show neuron as individual components or entire neuron
 vp = Plotter(shape=(1, 2), axes=1)
 vp.show(*list(components.values()), at=0, interactive=False)
-vp.show(neuron, at=1,interactive=True)
-
+vp.show(neuron, at=1, interactive=True)
